rawLine constant
String
const rawLine
Raw line - Treat the image as a single text line, bypassing hacks that are Tesseract-specific
Implementation
static const String rawLine = '12';
Raw line - Treat the image as a single text line, bypassing hacks that are Tesseract-specific
static const String rawLine = '12';