sparseText constant
String
const sparseText
Sparse text - Find as much text as possible in no particular order
Implementation
static const String sparseText = '10';
Sparse text - Find as much text as possible in no particular order
static const String sparseText = '10';