OCRConfig class
Configuration for OCR operations
Constructors
Properties
- engine → OCREngine
-
The OCR engine to use
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- language → String
-
The language to use for OCR
final
-
options
→ Map<
String, dynamic> ? -
Additional options for OCR engine
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tessDataPath → String?
-
Path to tessdata folder (only used with Tesseract engine)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Convert this configuration to a map that can be passed to the platform channel
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited