PageSegmentationMode class
Page Segmentation Modes for Tesseract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- auto → const String
- Fully automatic page segmentation, no OSD (default)
- autoOnly → const String
- Automatic page segmentation, no OSD, no OCR
- autoOsd → const String
- Automatic page segmentation with OSD
- osd → const String
- Orientation and script detection only
- rawLine → const String
- Raw line - Treat the image as a single text line, bypassing hacks that are Tesseract-specific
- singleBlock → const String
- Assume a single uniform block of text
- singleBlockVertText → const String
- Assume a single uniform block of vertically aligned text
- singleChar → const String
- Treat the image as a single character
- singleColumn → const String
- Assume a single column of text of variable sizes
- singleLine → const String
- Treat the image as a single text line
- singleWord → const String
- Treat the image as a single word
- sparseText → const String
- Sparse text - Find as much text as possible in no particular order
- sparseTextOsd → const String
- Sparse text with OSD